# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/userroleclass/v1/userroleclass.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKgithub.com/metaprov/modelaapi/services/userroleclass/v1/userroleclass.proto\x12\x37github.com.metaprov.modelaapi.services.userroleclass.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a google/protobuf/field_mask.proto\"\x88\x02\n\x1aListUserRoleClassesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12o\n\x06labels\x18\x02 \x03(\x0b\x32_.github.com.metaprov.modelaapi.services.userroleclass.v1.ListUserRoleClassesRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x01\n\x1bListUserRoleClassesResponse\x12W\n\x05roles\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.UserRoleClassList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x17\n\x15UserRoleClassResponse\"p\n\x1a\x43reateUserRoleClassRequest\x12R\n\x04role\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.UserRoleClass\"\x1d\n\x1b\x43reateUserRoleClassResponse\"\xa1\x01\n\x1aUpdateUserRoleClassRequest\x12R\n\x04role\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.UserRoleClass\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1d\n\x1bUpdateUserRoleClassResponse\":\n\x17GetUserRoleClassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"|\n\x18GetUserRoleClassResponse\x12R\n\x04role\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.UserRoleClass\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteUserRoleClassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteUserRoleClassResponse\"\x1d\n\x1bUserRoleClassCreateResponse\"N\n\x19UserRoleClassLoginRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"+\n\x1aUserRoleClassLoginResponse\x12\r\n\x05token\x18\x01 \x01(\t2\xd4\t\n\x14UserRoleClassService\x12\xe9\x01\n\x13ListUserRoleClasses\x12S.github.com.metaprov.modelaapi.services.userroleclass.v1.ListUserRoleClassesRequest\x1aT.github.com.metaprov.modelaapi.services.userroleclass.v1.ListUserRoleClassesResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/userroleclasses/{namespace}\x12\xe0\x01\n\x13\x43reateUserRoleClass\x12S.github.com.metaprov.modelaapi.services.userroleclass.v1.CreateUserRoleClassRequest\x1aT.github.com.metaprov.modelaapi.services.userroleclass.v1.CreateUserRoleClassResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/userroleclasses:\x01*\x12\xe7\x01\n\x10GetUserRoleClass\x12P.github.com.metaprov.modelaapi.services.userroleclass.v1.GetUserRoleClassRequest\x1aQ.github.com.metaprov.modelaapi.services.userroleclass.v1.GetUserRoleClassResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/userroleclasses/{namespace}/{name}\x12\x8f\x02\n\x13UpdateUserRoleClass\x12S.github.com.metaprov.modelaapi.services.userroleclass.v1.UpdateUserRoleClassRequest\x1aT.github.com.metaprov.modelaapi.services.userroleclass.v1.UpdateUserRoleClassResponse\"M\x82\xd3\xe4\x93\x02G\x1a\x42/v1/userroleclasses/{role.metadata.namespace}/{role.metadata.name}:\x01*\x12\xf0\x01\n\x13\x44\x65leteUserRoleClass\x12S.github.com.metaprov.modelaapi.services.userroleclass.v1.DeleteUserRoleClassRequest\x1aT.github.com.metaprov.modelaapi.services.userroleclass.v1.DeleteUserRoleClassResponse\".\x82\xd3\xe4\x93\x02(*&/v1/userroleclasses/{namespace}/{name}B9Z7github.com/metaprov/modelaapi/services/userroleclass/v1b\x06proto3')



_LISTUSERROLECLASSESREQUEST = DESCRIPTOR.message_types_by_name['ListUserRoleClassesRequest']
_LISTUSERROLECLASSESREQUEST_LABELSENTRY = _LISTUSERROLECLASSESREQUEST.nested_types_by_name['LabelsEntry']
_LISTUSERROLECLASSESRESPONSE = DESCRIPTOR.message_types_by_name['ListUserRoleClassesResponse']
_USERROLECLASSRESPONSE = DESCRIPTOR.message_types_by_name['UserRoleClassResponse']
_CREATEUSERROLECLASSREQUEST = DESCRIPTOR.message_types_by_name['CreateUserRoleClassRequest']
_CREATEUSERROLECLASSRESPONSE = DESCRIPTOR.message_types_by_name['CreateUserRoleClassResponse']
_UPDATEUSERROLECLASSREQUEST = DESCRIPTOR.message_types_by_name['UpdateUserRoleClassRequest']
_UPDATEUSERROLECLASSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateUserRoleClassResponse']
_GETUSERROLECLASSREQUEST = DESCRIPTOR.message_types_by_name['GetUserRoleClassRequest']
_GETUSERROLECLASSRESPONSE = DESCRIPTOR.message_types_by_name['GetUserRoleClassResponse']
_DELETEUSERROLECLASSREQUEST = DESCRIPTOR.message_types_by_name['DeleteUserRoleClassRequest']
_DELETEUSERROLECLASSRESPONSE = DESCRIPTOR.message_types_by_name['DeleteUserRoleClassResponse']
_USERROLECLASSCREATERESPONSE = DESCRIPTOR.message_types_by_name['UserRoleClassCreateResponse']
_USERROLECLASSLOGINREQUEST = DESCRIPTOR.message_types_by_name['UserRoleClassLoginRequest']
_USERROLECLASSLOGINRESPONSE = DESCRIPTOR.message_types_by_name['UserRoleClassLoginResponse']
ListUserRoleClassesRequest = _reflection.GeneratedProtocolMessageType('ListUserRoleClassesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTUSERROLECLASSESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.ListUserRoleClassesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTUSERROLECLASSESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.ListUserRoleClassesRequest)
  })
_sym_db.RegisterMessage(ListUserRoleClassesRequest)
_sym_db.RegisterMessage(ListUserRoleClassesRequest.LabelsEntry)

ListUserRoleClassesResponse = _reflection.GeneratedProtocolMessageType('ListUserRoleClassesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERROLECLASSESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.ListUserRoleClassesResponse)
  })
_sym_db.RegisterMessage(ListUserRoleClassesResponse)

UserRoleClassResponse = _reflection.GeneratedProtocolMessageType('UserRoleClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _USERROLECLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassResponse)
  })
_sym_db.RegisterMessage(UserRoleClassResponse)

CreateUserRoleClassRequest = _reflection.GeneratedProtocolMessageType('CreateUserRoleClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERROLECLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.CreateUserRoleClassRequest)
  })
_sym_db.RegisterMessage(CreateUserRoleClassRequest)

CreateUserRoleClassResponse = _reflection.GeneratedProtocolMessageType('CreateUserRoleClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERROLECLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.CreateUserRoleClassResponse)
  })
_sym_db.RegisterMessage(CreateUserRoleClassResponse)

UpdateUserRoleClassRequest = _reflection.GeneratedProtocolMessageType('UpdateUserRoleClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERROLECLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.UpdateUserRoleClassRequest)
  })
_sym_db.RegisterMessage(UpdateUserRoleClassRequest)

UpdateUserRoleClassResponse = _reflection.GeneratedProtocolMessageType('UpdateUserRoleClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERROLECLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.UpdateUserRoleClassResponse)
  })
_sym_db.RegisterMessage(UpdateUserRoleClassResponse)

GetUserRoleClassRequest = _reflection.GeneratedProtocolMessageType('GetUserRoleClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERROLECLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.GetUserRoleClassRequest)
  })
_sym_db.RegisterMessage(GetUserRoleClassRequest)

GetUserRoleClassResponse = _reflection.GeneratedProtocolMessageType('GetUserRoleClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERROLECLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.GetUserRoleClassResponse)
  })
_sym_db.RegisterMessage(GetUserRoleClassResponse)

DeleteUserRoleClassRequest = _reflection.GeneratedProtocolMessageType('DeleteUserRoleClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERROLECLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.DeleteUserRoleClassRequest)
  })
_sym_db.RegisterMessage(DeleteUserRoleClassRequest)

DeleteUserRoleClassResponse = _reflection.GeneratedProtocolMessageType('DeleteUserRoleClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERROLECLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.DeleteUserRoleClassResponse)
  })
_sym_db.RegisterMessage(DeleteUserRoleClassResponse)

UserRoleClassCreateResponse = _reflection.GeneratedProtocolMessageType('UserRoleClassCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _USERROLECLASSCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassCreateResponse)
  })
_sym_db.RegisterMessage(UserRoleClassCreateResponse)

UserRoleClassLoginRequest = _reflection.GeneratedProtocolMessageType('UserRoleClassLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERROLECLASSLOGINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassLoginRequest)
  })
_sym_db.RegisterMessage(UserRoleClassLoginRequest)

UserRoleClassLoginResponse = _reflection.GeneratedProtocolMessageType('UserRoleClassLoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _USERROLECLASSLOGINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassLoginResponse)
  })
_sym_db.RegisterMessage(UserRoleClassLoginResponse)

_USERROLECLASSSERVICE = DESCRIPTOR.services_by_name['UserRoleClassService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/metaprov/modelaapi/services/userroleclass/v1'
  _LISTUSERROLECLASSESREQUEST_LABELSENTRY._options = None
  _LISTUSERROLECLASSESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _USERROLECLASSSERVICE.methods_by_name['ListUserRoleClasses']._options = None
  _USERROLECLASSSERVICE.methods_by_name['ListUserRoleClasses']._serialized_options = b'\202\323\344\223\002!\022\037/v1/userroleclasses/{namespace}'
  _USERROLECLASSSERVICE.methods_by_name['CreateUserRoleClass']._options = None
  _USERROLECLASSSERVICE.methods_by_name['CreateUserRoleClass']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/userroleclasses:\001*'
  _USERROLECLASSSERVICE.methods_by_name['GetUserRoleClass']._options = None
  _USERROLECLASSSERVICE.methods_by_name['GetUserRoleClass']._serialized_options = b'\202\323\344\223\002(\022&/v1/userroleclasses/{namespace}/{name}'
  _USERROLECLASSSERVICE.methods_by_name['UpdateUserRoleClass']._options = None
  _USERROLECLASSSERVICE.methods_by_name['UpdateUserRoleClass']._serialized_options = b'\202\323\344\223\002G\032B/v1/userroleclasses/{role.metadata.namespace}/{role.metadata.name}:\001*'
  _USERROLECLASSSERVICE.methods_by_name['DeleteUserRoleClass']._options = None
  _USERROLECLASSSERVICE.methods_by_name['DeleteUserRoleClass']._serialized_options = b'\202\323\344\223\002(*&/v1/userroleclasses/{namespace}/{name}'
  _LISTUSERROLECLASSESREQUEST._serialized_start=335
  _LISTUSERROLECLASSESREQUEST._serialized_end=599
  _LISTUSERROLECLASSESREQUEST_LABELSENTRY._serialized_start=554
  _LISTUSERROLECLASSESREQUEST_LABELSENTRY._serialized_end=599
  _LISTUSERROLECLASSESRESPONSE._serialized_start=602
  _LISTUSERROLECLASSESRESPONSE._serialized_end=745
  _USERROLECLASSRESPONSE._serialized_start=747
  _USERROLECLASSRESPONSE._serialized_end=770
  _CREATEUSERROLECLASSREQUEST._serialized_start=772
  _CREATEUSERROLECLASSREQUEST._serialized_end=884
  _CREATEUSERROLECLASSRESPONSE._serialized_start=886
  _CREATEUSERROLECLASSRESPONSE._serialized_end=915
  _UPDATEUSERROLECLASSREQUEST._serialized_start=918
  _UPDATEUSERROLECLASSREQUEST._serialized_end=1079
  _UPDATEUSERROLECLASSRESPONSE._serialized_start=1081
  _UPDATEUSERROLECLASSRESPONSE._serialized_end=1110
  _GETUSERROLECLASSREQUEST._serialized_start=1112
  _GETUSERROLECLASSREQUEST._serialized_end=1170
  _GETUSERROLECLASSRESPONSE._serialized_start=1172
  _GETUSERROLECLASSRESPONSE._serialized_end=1296
  _DELETEUSERROLECLASSREQUEST._serialized_start=1298
  _DELETEUSERROLECLASSREQUEST._serialized_end=1359
  _DELETEUSERROLECLASSRESPONSE._serialized_start=1361
  _DELETEUSERROLECLASSRESPONSE._serialized_end=1390
  _USERROLECLASSCREATERESPONSE._serialized_start=1392
  _USERROLECLASSCREATERESPONSE._serialized_end=1421
  _USERROLECLASSLOGINREQUEST._serialized_start=1423
  _USERROLECLASSLOGINREQUEST._serialized_end=1501
  _USERROLECLASSLOGINRESPONSE._serialized_start=1503
  _USERROLECLASSLOGINRESPONSE._serialized_end=1546
  _USERROLECLASSSERVICE._serialized_start=1549
  _USERROLECLASSSERVICE._serialized_end=2785
# @@protoc_insertion_point(module_scope)
