# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.webrequest.v1 import webrequest_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2


class WebRequestServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListWebRequests = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/ListWebRequests',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.ListWebRequestsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.ListWebRequestsResponse.FromString,
                )
        self.CreateWebRequest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/CreateWebRequest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.CreateWebRequestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.CreateWebRequestResponse.FromString,
                )
        self.GetWebRequest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/GetWebRequest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.GetWebRequestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.GetWebRequestResponse.FromString,
                )
        self.UpdateWebRequest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/UpdateWebRequest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.UpdateWebRequestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.UpdateWebRequestResponse.FromString,
                )
        self.DeleteWebRequest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/DeleteWebRequest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.DeleteWebRequestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.DeleteWebRequestResponse.FromString,
                )
        self.RunWebRequest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/RunWebRequest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.RunWebRequestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.RunWebRequestResponse.FromString,
                )


class WebRequestServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListWebRequests(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWebRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWebRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWebRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteWebRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunWebRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WebRequestServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListWebRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWebRequests,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.ListWebRequestsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.ListWebRequestsResponse.SerializeToString,
            ),
            'CreateWebRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWebRequest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.CreateWebRequestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.CreateWebRequestResponse.SerializeToString,
            ),
            'GetWebRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWebRequest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.GetWebRequestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.GetWebRequestResponse.SerializeToString,
            ),
            'UpdateWebRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWebRequest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.UpdateWebRequestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.UpdateWebRequestResponse.SerializeToString,
            ),
            'DeleteWebRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteWebRequest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.DeleteWebRequestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.DeleteWebRequestResponse.SerializeToString,
            ),
            'RunWebRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.RunWebRequest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.RunWebRequestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.RunWebRequestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WebRequestService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListWebRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/ListWebRequests',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.ListWebRequestsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.ListWebRequestsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWebRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/CreateWebRequest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.CreateWebRequestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.CreateWebRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWebRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/GetWebRequest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.GetWebRequestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.GetWebRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWebRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/UpdateWebRequest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.UpdateWebRequestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.UpdateWebRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteWebRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/DeleteWebRequest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.DeleteWebRequestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.DeleteWebRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunWebRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/RunWebRequest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.RunWebRequestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.RunWebRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
