# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featureset/v1/featureset.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/featureset/v1/featureset.proto\x12\x34github.com.metaprov.modelaapi.services.featureset.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xfb\x01\n\x15ListFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12g\n\x06labels\x18\x02 \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x16ListFeaturesetResponse\x12Y\n\x0b\x66\x65\x61turesets\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturesetList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"o\n\x17\x43reateFeaturesetRequest\x12T\n\nfeatureset\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"\x1a\n\x18\x43reateFeaturesetResponse\"\x9f\x01\n\x17UpdateFeaturesetRequest\x12T\n\nfeatureset\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1a\n\x18UpdateFeaturesetResponse\"7\n\x14GetFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"{\n\x15GetFeaturesetResponse\x12T\n\nfeatureset\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65leteFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteFeaturesetResponse2\xf9\x08\n\x11\x46\x65\x61turesetService\x12\xd1\x01\n\x0fListFeaturesets\x12K.github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest\x1aL.github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/featuresets/{namespace}\x12\xcd\x01\n\x10\x43reateFeatureset\x12M.github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetRequest\x1aN.github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/featuresets:\x01*\x12\xd4\x01\n\rGetFeatureset\x12J.github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetRequest\x1aK.github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/featuresets/{namespace}/{name}\x12\x88\x02\n\x10UpdateFeatureset\x12M.github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetRequest\x1aN.github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/featuresets/{featureset.metadata.namespace}/{featureset.metadata.name}:\x01*\x12\xdd\x01\n\x10\x44\x65leteFeatureset\x12M.github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetRequest\x1aN.github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/featuresets/{namespace}/{name}B6Z4github.com/metaprov/modelaapi/services/featureset/v1b\x06proto3')



_LISTFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturesetRequest']
_LISTFEATURESETREQUEST_LABELSENTRY = _LISTFEATURESETREQUEST.nested_types_by_name['LabelsEntry']
_LISTFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturesetResponse']
_CREATEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['CreateFeaturesetRequest']
_CREATEFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['CreateFeaturesetResponse']
_UPDATEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeaturesetRequest']
_UPDATEFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeaturesetResponse']
_GETFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['GetFeaturesetRequest']
_GETFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['GetFeaturesetResponse']
_DELETEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeaturesetRequest']
_DELETEFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeaturesetResponse']
ListFeaturesetRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesetRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATURESETREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest)
  })
_sym_db.RegisterMessage(ListFeaturesetRequest)
_sym_db.RegisterMessage(ListFeaturesetRequest.LabelsEntry)

ListFeaturesetResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetResponse)
  })
_sym_db.RegisterMessage(ListFeaturesetResponse)

CreateFeaturesetRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetRequest)
  })
_sym_db.RegisterMessage(CreateFeaturesetRequest)

CreateFeaturesetResponse = _reflection.GeneratedProtocolMessageType('CreateFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetResponse)
  })
_sym_db.RegisterMessage(CreateFeaturesetResponse)

UpdateFeaturesetRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturesetRequest)

UpdateFeaturesetResponse = _reflection.GeneratedProtocolMessageType('UpdateFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetResponse)
  })
_sym_db.RegisterMessage(UpdateFeaturesetResponse)

GetFeaturesetRequest = _reflection.GeneratedProtocolMessageType('GetFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetRequest)
  })
_sym_db.RegisterMessage(GetFeaturesetRequest)

GetFeaturesetResponse = _reflection.GeneratedProtocolMessageType('GetFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetResponse)
  })
_sym_db.RegisterMessage(GetFeaturesetResponse)

DeleteFeaturesetRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturesetRequest)

DeleteFeaturesetResponse = _reflection.GeneratedProtocolMessageType('DeleteFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetResponse)
  })
_sym_db.RegisterMessage(DeleteFeaturesetResponse)

_FEATURESETSERVICE = DESCRIPTOR.services_by_name['FeaturesetService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/featureset/v1'
  _LISTFEATURESETREQUEST_LABELSENTRY._options = None
  _LISTFEATURESETREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _FEATURESETSERVICE.methods_by_name['ListFeaturesets']._options = None
  _FEATURESETSERVICE.methods_by_name['ListFeaturesets']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/featuresets/{namespace}'
  _FEATURESETSERVICE.methods_by_name['CreateFeatureset']._options = None
  _FEATURESETSERVICE.methods_by_name['CreateFeatureset']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/featuresets:\001*'
  _FEATURESETSERVICE.methods_by_name['GetFeatureset']._options = None
  _FEATURESETSERVICE.methods_by_name['GetFeatureset']._serialized_options = b'\202\323\344\223\002$\022\"/v1/featuresets/{namespace}/{name}'
  _FEATURESETSERVICE.methods_by_name['UpdateFeatureset']._options = None
  _FEATURESETSERVICE.methods_by_name['UpdateFeatureset']._serialized_options = b'\202\323\344\223\002O\032J/v1/featuresets/{featureset.metadata.namespace}/{featureset.metadata.name}:\001*'
  _FEATURESETSERVICE.methods_by_name['DeleteFeatureset']._options = None
  _FEATURESETSERVICE.methods_by_name['DeleteFeatureset']._serialized_options = b'\202\323\344\223\002$*\"/v1/featuresets/{namespace}/{name}'
  _LISTFEATURESETREQUEST._serialized_start=262
  _LISTFEATURESETREQUEST._serialized_end=513
  _LISTFEATURESETREQUEST_LABELSENTRY._serialized_start=468
  _LISTFEATURESETREQUEST_LABELSENTRY._serialized_end=513
  _LISTFEATURESETRESPONSE._serialized_start=516
  _LISTFEATURESETRESPONSE._serialized_end=656
  _CREATEFEATURESETREQUEST._serialized_start=658
  _CREATEFEATURESETREQUEST._serialized_end=769
  _CREATEFEATURESETRESPONSE._serialized_start=771
  _CREATEFEATURESETRESPONSE._serialized_end=797
  _UPDATEFEATURESETREQUEST._serialized_start=800
  _UPDATEFEATURESETREQUEST._serialized_end=959
  _UPDATEFEATURESETRESPONSE._serialized_start=961
  _UPDATEFEATURESETRESPONSE._serialized_end=987
  _GETFEATURESETREQUEST._serialized_start=989
  _GETFEATURESETREQUEST._serialized_end=1044
  _GETFEATURESETRESPONSE._serialized_start=1046
  _GETFEATURESETRESPONSE._serialized_end=1169
  _DELETEFEATURESETREQUEST._serialized_start=1171
  _DELETEFEATURESETREQUEST._serialized_end=1229
  _DELETEFEATURESETRESPONSE._serialized_start=1231
  _DELETEFEATURESETRESPONSE._serialized_end=1257
  _FEATURESETSERVICE._serialized_start=1260
  _FEATURESETSERVICE._serialized_end=2405
# @@protoc_insertion_point(module_scope)
