# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/review/v1/review.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=github.com/metaprov/modelaapi/services/review/v1/review.proto\x12\x30github.com.metaprov.modelaapi.services.review.v1\x1a google/protobuf/field_mask.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x1a\x1cgoogle/api/annotations.proto\"\xc2\x01\n\x10GetReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12^\n\x06labels\x18\x03 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x11GetReviewResponse\x12L\n\x06review\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"c\n\x13\x43reateReviewRequest\x12L\n\x06review\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x16\n\x14\x43reateReviewResponse\"\x93\x01\n\x13UpdateReviewRequest\x12L\n\x06review\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x16\n\x14UpdateReviewResponse\"\xc8\x01\n\x13\x44\x65leteReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x61\n\x06labels\x18\x03 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x16\n\x14\x44\x65leteReviewResponse\"\xdd\x01\n\x11ListReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12_\n\x06labels\x18\x02 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\x12ListReviewResponse\x12R\n\x08reviewes\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xf5\x07\n\rReviewService\x12\xb9\x01\n\x0bListReviews\x12\x43.github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest\x1a\x44.github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/reviews/{namespace}\x12\xb5\x01\n\x0c\x43reateReview\x12\x45.github.com.metaprov.modelaapi.services.review.v1.CreateReviewRequest\x1a\x46.github.com.metaprov.modelaapi.services.review.v1.CreateReviewResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/reviews:\x01*\x12\xbc\x01\n\tGetReview\x12\x42.github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest\x1a\x43.github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/reviews/{namespace}/{name}\x12\xe8\x01\n\x0cUpdateReview\x12\x45.github.com.metaprov.modelaapi.services.review.v1.UpdateReviewRequest\x1a\x46.github.com.metaprov.modelaapi.services.review.v1.UpdateReviewResponse\"I\x82\xd3\xe4\x93\x02\x43\x1a>/v1/reviews/{review.metadata.namespace}/{review.metadata.name}:\x01*\x12\xc5\x01\n\x0c\x44\x65leteReview\x12\x45.github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest\x1a\x46.github.com.metaprov.modelaapi.services.review.v1.DeleteReviewResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1/reviews/{namespace}/{name}B2Z0github.com/metaprov/modelaapi/services/review/v1b\x06proto3')



_GETREVIEWREQUEST = DESCRIPTOR.message_types_by_name['GetReviewRequest']
_GETREVIEWREQUEST_LABELSENTRY = _GETREVIEWREQUEST.nested_types_by_name['LabelsEntry']
_GETREVIEWRESPONSE = DESCRIPTOR.message_types_by_name['GetReviewResponse']
_CREATEREVIEWREQUEST = DESCRIPTOR.message_types_by_name['CreateReviewRequest']
_CREATEREVIEWRESPONSE = DESCRIPTOR.message_types_by_name['CreateReviewResponse']
_UPDATEREVIEWREQUEST = DESCRIPTOR.message_types_by_name['UpdateReviewRequest']
_UPDATEREVIEWRESPONSE = DESCRIPTOR.message_types_by_name['UpdateReviewResponse']
_DELETEREVIEWREQUEST = DESCRIPTOR.message_types_by_name['DeleteReviewRequest']
_DELETEREVIEWREQUEST_LABELSENTRY = _DELETEREVIEWREQUEST.nested_types_by_name['LabelsEntry']
_DELETEREVIEWRESPONSE = DESCRIPTOR.message_types_by_name['DeleteReviewResponse']
_LISTREVIEWREQUEST = DESCRIPTOR.message_types_by_name['ListReviewRequest']
_LISTREVIEWREQUEST_LABELSENTRY = _LISTREVIEWREQUEST.nested_types_by_name['LabelsEntry']
_LISTREVIEWRESPONSE = DESCRIPTOR.message_types_by_name['ListReviewResponse']
GetReviewRequest = _reflection.GeneratedProtocolMessageType('GetReviewRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETREVIEWREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest)
  })
_sym_db.RegisterMessage(GetReviewRequest)
_sym_db.RegisterMessage(GetReviewRequest.LabelsEntry)

GetReviewResponse = _reflection.GeneratedProtocolMessageType('GetReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETREVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse)
  })
_sym_db.RegisterMessage(GetReviewResponse)

CreateReviewRequest = _reflection.GeneratedProtocolMessageType('CreateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.CreateReviewRequest)
  })
_sym_db.RegisterMessage(CreateReviewRequest)

CreateReviewResponse = _reflection.GeneratedProtocolMessageType('CreateReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.CreateReviewResponse)
  })
_sym_db.RegisterMessage(CreateReviewResponse)

UpdateReviewRequest = _reflection.GeneratedProtocolMessageType('UpdateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.UpdateReviewRequest)
  })
_sym_db.RegisterMessage(UpdateReviewRequest)

UpdateReviewResponse = _reflection.GeneratedProtocolMessageType('UpdateReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.UpdateReviewResponse)
  })
_sym_db.RegisterMessage(UpdateReviewResponse)

DeleteReviewRequest = _reflection.GeneratedProtocolMessageType('DeleteReviewRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DELETEREVIEWREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _DELETEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest)
  })
_sym_db.RegisterMessage(DeleteReviewRequest)
_sym_db.RegisterMessage(DeleteReviewRequest.LabelsEntry)

DeleteReviewResponse = _reflection.GeneratedProtocolMessageType('DeleteReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.DeleteReviewResponse)
  })
_sym_db.RegisterMessage(DeleteReviewResponse)

ListReviewRequest = _reflection.GeneratedProtocolMessageType('ListReviewRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTREVIEWREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest)
  })
_sym_db.RegisterMessage(ListReviewRequest)
_sym_db.RegisterMessage(ListReviewRequest.LabelsEntry)

ListReviewResponse = _reflection.GeneratedProtocolMessageType('ListReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse)
  })
_sym_db.RegisterMessage(ListReviewResponse)

_REVIEWSERVICE = DESCRIPTOR.services_by_name['ReviewService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/metaprov/modelaapi/services/review/v1'
  _GETREVIEWREQUEST_LABELSENTRY._options = None
  _GETREVIEWREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DELETEREVIEWREQUEST_LABELSENTRY._options = None
  _DELETEREVIEWREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTREVIEWREQUEST_LABELSENTRY._options = None
  _LISTREVIEWREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _REVIEWSERVICE.methods_by_name['ListReviews']._options = None
  _REVIEWSERVICE.methods_by_name['ListReviews']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/reviews/{namespace}'
  _REVIEWSERVICE.methods_by_name['CreateReview']._options = None
  _REVIEWSERVICE.methods_by_name['CreateReview']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/reviews:\001*'
  _REVIEWSERVICE.methods_by_name['GetReview']._options = None
  _REVIEWSERVICE.methods_by_name['GetReview']._serialized_options = b'\202\323\344\223\002 \022\036/v1/reviews/{namespace}/{name}'
  _REVIEWSERVICE.methods_by_name['UpdateReview']._options = None
  _REVIEWSERVICE.methods_by_name['UpdateReview']._serialized_options = b'\202\323\344\223\002C\032>/v1/reviews/{review.metadata.namespace}/{review.metadata.name}:\001*'
  _REVIEWSERVICE.methods_by_name['DeleteReview']._options = None
  _REVIEWSERVICE.methods_by_name['DeleteReview']._serialized_options = b'\202\323\344\223\002 *\036/v1/reviews/{namespace}/{name}'
  _GETREVIEWREQUEST._serialized_start=279
  _GETREVIEWREQUEST._serialized_end=473
  _GETREVIEWREQUEST_LABELSENTRY._serialized_start=428
  _GETREVIEWREQUEST_LABELSENTRY._serialized_end=473
  _GETREVIEWRESPONSE._serialized_start=475
  _GETREVIEWRESPONSE._serialized_end=586
  _CREATEREVIEWREQUEST._serialized_start=588
  _CREATEREVIEWREQUEST._serialized_end=687
  _CREATEREVIEWRESPONSE._serialized_start=689
  _CREATEREVIEWRESPONSE._serialized_end=711
  _UPDATEREVIEWREQUEST._serialized_start=714
  _UPDATEREVIEWREQUEST._serialized_end=861
  _UPDATEREVIEWRESPONSE._serialized_start=863
  _UPDATEREVIEWRESPONSE._serialized_end=885
  _DELETEREVIEWREQUEST._serialized_start=888
  _DELETEREVIEWREQUEST._serialized_end=1088
  _DELETEREVIEWREQUEST_LABELSENTRY._serialized_start=428
  _DELETEREVIEWREQUEST_LABELSENTRY._serialized_end=473
  _DELETEREVIEWRESPONSE._serialized_start=1090
  _DELETEREVIEWRESPONSE._serialized_end=1112
  _LISTREVIEWREQUEST._serialized_start=1115
  _LISTREVIEWREQUEST._serialized_end=1336
  _LISTREVIEWREQUEST_LABELSENTRY._serialized_start=428
  _LISTREVIEWREQUEST_LABELSENTRY._serialized_end=473
  _LISTREVIEWRESPONSE._serialized_start=1339
  _LISTREVIEWRESPONSE._serialized_end=1468
  _REVIEWSERVICE._serialized_start=1471
  _REVIEWSERVICE._serialized_end=2484
# @@protoc_insertion_point(module_scope)
