# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/notebook/v1/notebook.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAgithub.com/metaprov/modelaapi/services/notebook/v1/notebook.proto\x12\x32github.com.metaprov.modelaapi.services.notebook.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xf7\x01\n\x14ListNotebooksRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x64\n\x06labels\x18\x02 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x01\n\x15ListNotebooksResponse\x12Y\n\tnotebooks\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x12\n\x10NotebookResponse\"m\n\x15\x43reateNotebookRequest\x12T\n\x08notebook\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"\x18\n\x16\x43reateNotebookResponse\"\x9d\x01\n\x15UpdateNotebookRequest\x12T\n\x08notebook\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x18\n\x16UpdateNotebookResponse\"5\n\x12GetNotebookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x13GetNotebookResponse\x12T\n\x08notebook\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"8\n\x15\x44\x65leteNotebookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteNotebookResponse2\xad\x08\n\x0fNotebookService\x12\xbb\x01\n\rListNotebooks\x12H.github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest\x1aI.github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v1/notebooks\x12\xc1\x01\n\x0e\x43reateNotebook\x12I.github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookRequest\x1aJ.github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookResponse\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/notebooks:\x01*\x12\xc8\x01\n\x0bGetNotebook\x12\x46.github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookRequest\x1aG.github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/notebooks/{namespace}/{name}\x12\xf8\x01\n\x0eUpdateNotebook\x12I.github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookRequest\x1aJ.github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookResponse\"O\x82\xd3\xe4\x93\x02I\x1a\x44/v1/notebooks/{notebook.metadata.namespace}/{notebook.metadata.name}:\x01*\x12\xd1\x01\n\x0e\x44\x65leteNotebook\x12I.github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookRequest\x1aJ.github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookResponse\"(\x82\xd3\xe4\x93\x02\"* /v1/notebooks/{namespace}/{name}B4Z2github.com/metaprov/modelaapi/services/notebook/v1b\x06proto3')



_LISTNOTEBOOKSREQUEST = DESCRIPTOR.message_types_by_name['ListNotebooksRequest']
_LISTNOTEBOOKSREQUEST_LABELSENTRY = _LISTNOTEBOOKSREQUEST.nested_types_by_name['LabelsEntry']
_LISTNOTEBOOKSRESPONSE = DESCRIPTOR.message_types_by_name['ListNotebooksResponse']
_NOTEBOOKRESPONSE = DESCRIPTOR.message_types_by_name['NotebookResponse']
_CREATENOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['CreateNotebookRequest']
_CREATENOTEBOOKRESPONSE = DESCRIPTOR.message_types_by_name['CreateNotebookResponse']
_UPDATENOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['UpdateNotebookRequest']
_UPDATENOTEBOOKRESPONSE = DESCRIPTOR.message_types_by_name['UpdateNotebookResponse']
_GETNOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['GetNotebookRequest']
_GETNOTEBOOKRESPONSE = DESCRIPTOR.message_types_by_name['GetNotebookResponse']
_DELETENOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['DeleteNotebookRequest']
_DELETENOTEBOOKRESPONSE = DESCRIPTOR.message_types_by_name['DeleteNotebookResponse']
ListNotebooksRequest = _reflection.GeneratedProtocolMessageType('ListNotebooksRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTNOTEBOOKSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTNOTEBOOKSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest)
  })
_sym_db.RegisterMessage(ListNotebooksRequest)
_sym_db.RegisterMessage(ListNotebooksRequest.LabelsEntry)

ListNotebooksResponse = _reflection.GeneratedProtocolMessageType('ListNotebooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksResponse)
  })
_sym_db.RegisterMessage(ListNotebooksResponse)

NotebookResponse = _reflection.GeneratedProtocolMessageType('NotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.NotebookResponse)
  })
_sym_db.RegisterMessage(NotebookResponse)

CreateNotebookRequest = _reflection.GeneratedProtocolMessageType('CreateNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookRequest)
  })
_sym_db.RegisterMessage(CreateNotebookRequest)

CreateNotebookResponse = _reflection.GeneratedProtocolMessageType('CreateNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookResponse)
  })
_sym_db.RegisterMessage(CreateNotebookResponse)

UpdateNotebookRequest = _reflection.GeneratedProtocolMessageType('UpdateNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookRequest)
  })
_sym_db.RegisterMessage(UpdateNotebookRequest)

UpdateNotebookResponse = _reflection.GeneratedProtocolMessageType('UpdateNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookResponse)
  })
_sym_db.RegisterMessage(UpdateNotebookResponse)

GetNotebookRequest = _reflection.GeneratedProtocolMessageType('GetNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookRequest)
  })
_sym_db.RegisterMessage(GetNotebookRequest)

GetNotebookResponse = _reflection.GeneratedProtocolMessageType('GetNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookResponse)
  })
_sym_db.RegisterMessage(GetNotebookResponse)

DeleteNotebookRequest = _reflection.GeneratedProtocolMessageType('DeleteNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookRequest)
  })
_sym_db.RegisterMessage(DeleteNotebookRequest)

DeleteNotebookResponse = _reflection.GeneratedProtocolMessageType('DeleteNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookResponse)
  })
_sym_db.RegisterMessage(DeleteNotebookResponse)

_NOTEBOOKSERVICE = DESCRIPTOR.services_by_name['NotebookService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/metaprov/modelaapi/services/notebook/v1'
  _LISTNOTEBOOKSREQUEST_LABELSENTRY._options = None
  _LISTNOTEBOOKSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _NOTEBOOKSERVICE.methods_by_name['ListNotebooks']._options = None
  _NOTEBOOKSERVICE.methods_by_name['ListNotebooks']._serialized_options = b'\202\323\344\223\002\017\022\r/v1/notebooks'
  _NOTEBOOKSERVICE.methods_by_name['CreateNotebook']._options = None
  _NOTEBOOKSERVICE.methods_by_name['CreateNotebook']._serialized_options = b'\202\323\344\223\002\022\"\r/v1/notebooks:\001*'
  _NOTEBOOKSERVICE.methods_by_name['GetNotebook']._options = None
  _NOTEBOOKSERVICE.methods_by_name['GetNotebook']._serialized_options = b'\202\323\344\223\002\"\022 /v1/notebooks/{namespace}/{name}'
  _NOTEBOOKSERVICE.methods_by_name['UpdateNotebook']._options = None
  _NOTEBOOKSERVICE.methods_by_name['UpdateNotebook']._serialized_options = b'\202\323\344\223\002I\032D/v1/notebooks/{notebook.metadata.namespace}/{notebook.metadata.name}:\001*'
  _NOTEBOOKSERVICE.methods_by_name['DeleteNotebook']._options = None
  _NOTEBOOKSERVICE.methods_by_name['DeleteNotebook']._serialized_options = b'\202\323\344\223\002\"* /v1/notebooks/{namespace}/{name}'
  _LISTNOTEBOOKSREQUEST._serialized_start=323
  _LISTNOTEBOOKSREQUEST._serialized_end=570
  _LISTNOTEBOOKSREQUEST_LABELSENTRY._serialized_start=525
  _LISTNOTEBOOKSREQUEST_LABELSENTRY._serialized_end=570
  _LISTNOTEBOOKSRESPONSE._serialized_start=573
  _LISTNOTEBOOKSRESPONSE._serialized_end=712
  _NOTEBOOKRESPONSE._serialized_start=714
  _NOTEBOOKRESPONSE._serialized_end=732
  _CREATENOTEBOOKREQUEST._serialized_start=734
  _CREATENOTEBOOKREQUEST._serialized_end=843
  _CREATENOTEBOOKRESPONSE._serialized_start=845
  _CREATENOTEBOOKRESPONSE._serialized_end=869
  _UPDATENOTEBOOKREQUEST._serialized_start=872
  _UPDATENOTEBOOKREQUEST._serialized_end=1029
  _UPDATENOTEBOOKRESPONSE._serialized_start=1031
  _UPDATENOTEBOOKRESPONSE._serialized_end=1055
  _GETNOTEBOOKREQUEST._serialized_start=1057
  _GETNOTEBOOKREQUEST._serialized_end=1110
  _GETNOTEBOOKRESPONSE._serialized_start=1112
  _GETNOTEBOOKRESPONSE._serialized_end=1233
  _DELETENOTEBOOKREQUEST._serialized_start=1235
  _DELETENOTEBOOKREQUEST._serialized_end=1291
  _DELETENOTEBOOKRESPONSE._serialized_start=1293
  _DELETENOTEBOOKRESPONSE._serialized_end=1317
  _NOTEBOOKSERVICE._serialized_start=1320
  _NOTEBOOKSERVICE._serialized_end=2389
# @@protoc_insertion_point(module_scope)
