# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/review/v1/review.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/review/v1/review.proto',
  package='github.com.metaprov.modelaapi.services.review.v1',
  syntax='proto3',
  serialized_options=b'Z6github.com/metaprov/modelaapi/services/review/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nIgithub.com/metaprov/modelaapi/services/review/v1/review.proto\x12\x36github.com.metaprov.modelaapi.services.review.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x1a\x1cgoogle/api/annotations.proto\"\xd4\x01\n\x16GetReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12j\n\x06labels\x18\x03 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x17GetReviewResponse\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"m\n\x19\x43reateReviewRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x1c\n\x1a\x43reateReviewResponse\"m\n\x19UpdateReviewRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x1c\n\x1aUpdateReviewResponse\"\xda\x01\n\x19\x44\x65leteReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12m\n\x06labels\x18\x03 \x03(\x0b\x32].github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1c\n\x1a\x44\x65leteReviewResponse\"\xef\x01\n\x17ListReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12k\n\x06labels\x18\x02 \x03(\x0b\x32[.github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8a\x01\n\x18ListReviewResponse\x12U\n\x05items\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe7\t\n\x13\x43onversationService\x12\xe7\x01\n\x11ListReviews\x12O.github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest\x1aP.github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/api/v1alpha1/reviews/{namespace}\x12\xe3\x01\n\x12\x43reateReview\x12Q.github.com.metaprov.modelaapi.services.review.v1.CreateReviewRequest\x1aR.github.com.metaprov.modelaapi.services.review.v1.CreateReviewResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/api/v1alpha1/reviews:\x01*\x12\xea\x01\n\x0fGetReview\x12N.github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest\x1aO.github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./api/v1alpha1/reviews/{namespace}/{name}\x12\xa2\x02\n\x12UpdateReview\x12Q.github.com.metaprov.modelaapi.services.review.v1.UpdateReviewRequest\x1aR.github.com.metaprov.modelaapi.services.review.v1.UpdateReviewResponse\"e\x82\xd3\xe4\x93\x02_\x1aZ/api/v1alpha1/reviews/{review.metadata.namespace}/{review.metadata.name}:\x01*\x12\xed\x01\n\x12\x44\x65leteReview\x12Q.github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest\x1aR.github.com.metaprov.modelaapi.services.review.v1.DeleteReviewResponse\"0\x82\xd3\xe4\x93\x02**(/api/v1/reviews/{namespace}/{name}B8Z6github.com/metaprov/modelaapi/services/review/v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETCONVERSATIONREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=475,
)

_GETCONVERSATIONREQUEST = _descriptor.Descriptor(
  name='GetReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETCONVERSATIONREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=475,
)


_GETCONVERSATIONRESPONSE = _descriptor.Descriptor(
  name='GetReviewResponse',
  full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=598,
)


_CREATECONVERSATIONREQUEST = _descriptor.Descriptor(
  name='CreateReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.review.v1.CreateReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.review.v1.CreateReviewRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=600,
  serialized_end=709,
)


_CREATECONVERSATIONRESPONSE = _descriptor.Descriptor(
  name='CreateReviewResponse',
  full_name='github.com.metaprov.modelaapi.services.review.v1.CreateReviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=739,
)


_UPDATECONVERSATIONREQUEST = _descriptor.Descriptor(
  name='UpdateReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.review.v1.UpdateReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.review.v1.UpdateReviewRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=850,
)


_UPDATECONVERSATIONRESPONSE = _descriptor.Descriptor(
  name='UpdateReviewResponse',
  full_name='github.com.metaprov.modelaapi.services.review.v1.UpdateReviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=880,
)


_DELETECONVERSATIONREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=475,
)

_DELETECONVERSATIONREQUEST = _descriptor.Descriptor(
  name='DeleteReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DELETECONVERSATIONREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=1101,
)


_DELETECONVERSATIONRESPONSE = _descriptor.Descriptor(
  name='DeleteReviewResponse',
  full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1103,
  serialized_end=1131,
)


_LISTCONVERSATIONREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=475,
)

_LISTCONVERSATIONREQUEST = _descriptor.Descriptor(
  name='ListReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.page_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTCONVERSATIONREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1373,
)


_LISTCONVERSATIONRESPONSE = _descriptor.Descriptor(
  name='ListReviewResponse',
  full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1376,
  serialized_end=1514,
)

_GETCONVERSATIONREQUEST_LABELSENTRY.containing_type = _GETCONVERSATIONREQUEST
_GETCONVERSATIONREQUEST.fields_by_name['labels'].message_type = _GETCONVERSATIONREQUEST_LABELSENTRY
_GETCONVERSATIONRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._CONVERSATION
_CREATECONVERSATIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._CONVERSATION
_UPDATECONVERSATIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._CONVERSATION
_DELETECONVERSATIONREQUEST_LABELSENTRY.containing_type = _DELETECONVERSATIONREQUEST
_DELETECONVERSATIONREQUEST.fields_by_name['labels'].message_type = _DELETECONVERSATIONREQUEST_LABELSENTRY
_LISTCONVERSATIONREQUEST_LABELSENTRY.containing_type = _LISTCONVERSATIONREQUEST
_LISTCONVERSATIONREQUEST.fields_by_name['labels'].message_type = _LISTCONVERSATIONREQUEST_LABELSENTRY
_LISTCONVERSATIONRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._CONVERSATIONLIST
DESCRIPTOR.message_types_by_name['GetReviewRequest'] = _GETCONVERSATIONREQUEST
DESCRIPTOR.message_types_by_name['GetReviewResponse'] = _GETCONVERSATIONRESPONSE
DESCRIPTOR.message_types_by_name['CreateReviewRequest'] = _CREATECONVERSATIONREQUEST
DESCRIPTOR.message_types_by_name['CreateReviewResponse'] = _CREATECONVERSATIONRESPONSE
DESCRIPTOR.message_types_by_name['UpdateReviewRequest'] = _UPDATECONVERSATIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateReviewResponse'] = _UPDATECONVERSATIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteReviewRequest'] = _DELETECONVERSATIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteReviewResponse'] = _DELETECONVERSATIONRESPONSE
DESCRIPTOR.message_types_by_name['ListReviewRequest'] = _LISTCONVERSATIONREQUEST
DESCRIPTOR.message_types_by_name['ListReviewResponse'] = _LISTCONVERSATIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetReviewRequest = _reflection.GeneratedProtocolMessageType('GetReviewRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCONVERSATIONREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETCONVERSATIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest)
  })
_sym_db.RegisterMessage(GetReviewRequest)
_sym_db.RegisterMessage(GetReviewRequest.LabelsEntry)

GetReviewResponse = _reflection.GeneratedProtocolMessageType('GetReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONVERSATIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse)
  })
_sym_db.RegisterMessage(GetReviewResponse)

CreateReviewRequest = _reflection.GeneratedProtocolMessageType('CreateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONVERSATIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.CreateReviewRequest)
  })
_sym_db.RegisterMessage(CreateReviewRequest)

CreateReviewResponse = _reflection.GeneratedProtocolMessageType('CreateReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONVERSATIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.CreateReviewResponse)
  })
_sym_db.RegisterMessage(CreateReviewResponse)

UpdateReviewRequest = _reflection.GeneratedProtocolMessageType('UpdateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONVERSATIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.UpdateReviewRequest)
  })
_sym_db.RegisterMessage(UpdateReviewRequest)

UpdateReviewResponse = _reflection.GeneratedProtocolMessageType('UpdateReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONVERSATIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.UpdateReviewResponse)
  })
_sym_db.RegisterMessage(UpdateReviewResponse)

DeleteReviewRequest = _reflection.GeneratedProtocolMessageType('DeleteReviewRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DELETECONVERSATIONREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _DELETECONVERSATIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest)
  })
_sym_db.RegisterMessage(DeleteReviewRequest)
_sym_db.RegisterMessage(DeleteReviewRequest.LabelsEntry)

DeleteReviewResponse = _reflection.GeneratedProtocolMessageType('DeleteReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONVERSATIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.DeleteReviewResponse)
  })
_sym_db.RegisterMessage(DeleteReviewResponse)

ListReviewRequest = _reflection.GeneratedProtocolMessageType('ListReviewRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCONVERSATIONREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCONVERSATIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest)
  })
_sym_db.RegisterMessage(ListReviewRequest)
_sym_db.RegisterMessage(ListReviewRequest.LabelsEntry)

ListReviewResponse = _reflection.GeneratedProtocolMessageType('ListReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONVERSATIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse)
  })
_sym_db.RegisterMessage(ListReviewResponse)


DESCRIPTOR._options = None
_GETCONVERSATIONREQUEST_LABELSENTRY._options = None
_DELETECONVERSATIONREQUEST_LABELSENTRY._options = None
_LISTCONVERSATIONREQUEST_LABELSENTRY._options = None

_CONVERSATIONSERVICE = _descriptor.ServiceDescriptor(
  name='ReviewService',
  full_name='github.com.metaprov.modelaapi.services.review.v1.ReviewService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1517,
  serialized_end=2772,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListReviews',
    full_name='github.com.metaprov.modelaapi.services.review.v1.ReviewService.ListReviews',
    index=0,
    containing_service=None,
    input_type=_LISTCONVERSATIONREQUEST,
    output_type=_LISTCONVERSATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002)\022\'/api/v1alpha1/reviews/{namespace}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateReview',
    full_name='github.com.metaprov.modelaapi.services.review.v1.ReviewService.CreateReview',
    index=1,
    containing_service=None,
    input_type=_CREATECONVERSATIONREQUEST,
    output_type=_CREATECONVERSATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002 \"\033/api/v1alpha1/reviews:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetReview',
    full_name='github.com.metaprov.modelaapi.services.review.v1.ReviewService.GetReview',
    index=2,
    containing_service=None,
    input_type=_GETCONVERSATIONREQUEST,
    output_type=_GETCONVERSATIONRESPONSE,
    serialized_options=b'\202\323\344\223\0020\022./api/v1alpha1/reviews/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateReview',
    full_name='github.com.metaprov.modelaapi.services.review.v1.ReviewService.UpdateReview',
    index=3,
    containing_service=None,
    input_type=_UPDATECONVERSATIONREQUEST,
    output_type=_UPDATECONVERSATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002_\032Z/api/v1alpha1/reviews/{review.metadata.namespace}/{review.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteReview',
    full_name='github.com.metaprov.modelaapi.services.review.v1.ReviewService.DeleteReview',
    index=4,
    containing_service=None,
    input_type=_DELETECONVERSATIONREQUEST,
    output_type=_DELETECONVERSATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002**(/api/v1/reviews/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONVERSATIONSERVICE)

DESCRIPTOR.services_by_name['ReviewService'] = _CONVERSATIONSERVICE

# @@protoc_insertion_point(module_scope)
